#!/bin/sh
# Script library for doing common things that xdotool doesn't provide
# - Getting the root window ID
# - Getting width/height/position/state information about windows

error() {
  echo "$@" >&2
}

rootwindow() {
  xwininfo -root | awk '/Window id:/ { print $4 }'
}

# This function outputs shell variables, and as such should be used
# like this example:
# eval $(_xwininfo WINDOID)
# # Now $width, $xpos, etc are available
_xwininfo() {
  if [ -z "$1" ] ; then
    error "_xwininfo: No window id given."
    return 1
  fi

  xwininfo -id "$1" \
  | awk '
    /Width:/ { print "width="$2 }
    /Height:/ { print "height="$2 }
    /Absolute upper-left X:/ { print "xpos="$4 }
    /Absolute upper-left Y:/ { print "ypos="$4 }
    /Map State:/ { print "visible=" ($2 == "IsViewable" ? 1 : 0) }
    /Override Redirect State:/ { print "override_redirect="$2 }
    /xwininfo: Window id: / { 
      for (i = 1; i <= 4; i++) {
        $i = "";
      }
      title=substr($0,6, length($0) - 7)
      gsub(/["]/, "\\\&", title)
      print "title=\""title"\""
    }
  '
}
